@@ -17,6 +17,13 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
+/**
+ * \addtogroup PedTimer
+ * @{
+ */
+
+/** \file timer.h */
+
 #ifndef PED_TIMER_H_INCLUDED
 #define PED_TIMER_H_INCLUDED
 
@@ -26,14 +33,17 @@ typedef struct _PedTimer PedTimer;
 
 typedef void PedTimerHandler (PedTimer* timer, void* context);
 
+/*
+ * Structure keeping track of progress and time
+ */
 struct _PedTimer {
-	float			frac;		/* fraction of operation done */
-	time_t			start;		/* time of start of op */
-	time_t			now;		/* time of last update (now!) */
-	time_t			predicted_end;	/* expected finish time */
-	const char*		state_name;	/* eg: "copying data" */
-	PedTimerHandler*	handler;	/* who to notify on updates */
-	void*			context;	/* context to pass to handler */
+	float			frac;		/**< fraction of operation done */
+	time_t			start;		/**< time of start of op */
+	time_t			now;		/**< time of last update (now!) */
+	time_t			predicted_end;	/**< expected finish time */
+	const char*		state_name;	/**< eg: "copying data" */
+	PedTimerHandler*	handler;	/**< who to notify on updates */
+	void*			context;	/**< context to pass to handler */
 };
 
 extern PedTimer* ped_timer_new (PedTimerHandler* handler, void* context);
@@ -52,3 +62,5 @@ extern void ped_timer_set_state_name (PedTimer* timer, const char* state_name);
 
 #endif /* PED_TIMER_H_INCLUDED */
 
+
+/** @} */
