@@ -1,6 +1,6 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+    Copyright (C) 1999, 2000, 2001, 2007 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,20 +17,20 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#include "config.h"
+#include <config.h>
+#include "configmake.h"
 
 #include <parted/parted.h>
 #include <parted/debug.h>
 
 #ifdef linux
 #  include <parted/linux.h>
+#elif defined(__BEOS__)
+#  include <parted/beos.h>
 #else
 #  include <parted/gnu.h>
 #endif
 
-#include <string.h>
-#include <stdlib.h>
-
 #if ENABLE_NLS
 #  include <locale.h>
 #  include <libintl.h>
@@ -78,6 +78,7 @@ ped_set_architecture (const PedArchitecture* arch)
 	return 1;
 }
 
+extern void ped_disk_aix_init ();
 extern void ped_disk_bsd_init ();
 extern void ped_disk_dvh_init ();
 extern void ped_disk_gpt_init ();
@@ -87,12 +88,17 @@ extern void ped_disk_msdos_init ();
 extern void ped_disk_pc98_init ();
 extern void ped_disk_sun_init ();
 extern void ped_disk_amiga_init ();
+extern void ped_disk_dasd_init ();
 
 static void
 init_disk_types ()
 {
 	ped_disk_loop_init ();	/* must be last in the probe list */
 
+#if defined(__s390__) || defined(__s390x__)
+	ped_disk_dasd_init();
+#endif
+
 	ped_disk_sun_init ();
 #ifdef ENABLE_PC98
 	ped_disk_pc98_init ();
@@ -103,6 +109,7 @@ init_disk_types ()
 	ped_disk_dvh_init ();
 	ped_disk_bsd_init ();
 	ped_disk_amiga_init ();
+	ped_disk_aix_init ();
 }
 
 #ifdef ENABLE_FS
@@ -133,6 +140,7 @@ init_file_system_types ()
 }
 #endif /* ENABLE_FS */
 
+extern void ped_disk_aix_done ();
 extern void ped_disk_bsd_done ();
 extern void ped_disk_dvh_done ();
 extern void ped_disk_gpt_done ();
@@ -142,10 +150,14 @@ extern void ped_disk_msdos_done ();
 extern void ped_disk_pc98_done ();
 extern void ped_disk_sun_done ();
 extern void ped_disk_amiga_done ();
+extern void ped_disk_dasd_done ();
 
 static void
 done_disk_types ()
 {
+#if defined(__s390__) || (__s390x__)
+	ped_disk_dasd_done ();
+#endif
 	ped_disk_sun_done ();
 #ifdef ENABLE_PC98
 	ped_disk_pc98_done ();
@@ -157,6 +169,7 @@ done_disk_types ()
 	ped_disk_dvh_done ();
 	ped_disk_bsd_done ();
 	ped_disk_amiga_done ();
+	ped_disk_aix_done ();
 }
 
 static void _init() __attribute__ ((constructor));
@@ -177,6 +190,8 @@ _init()
 	/* FIXME: a better way of doing this? */
 #ifdef linux
 	ped_set_architecture (&ped_linux_arch);
+#elif defined(__BEOS__)
+	ped_set_architecture (&ped_beos_arch);
 #else
 	ped_set_architecture (&ped_gnu_arch);
 #endif
@@ -305,6 +320,17 @@ ped_realloc (void** old, size_t size)
 	return 1;
 }
 
+
+void* ped_calloc (size_t size)
+{
+        void* buf = ped_malloc (size);
+
+        memset (buf, 0, size);
+
+        return buf;
+}
+
+
 void
 ped_free (void* ptr)
 {
